@@ -13,10 +13,10 @@ test_that("ebirdloc works correctly", {
   
   simpler <- ebirdloc('L99381', max = 1, simple = TRUE)
   lesssimpler <- ebirdloc('L99381', max = 1, simple = FALSE)
-  expect_less_than(NCOL(simpler), 15)
-  expect_that(NCOL(simpler), not(is_less_than(8)))
-  expect_less_than(NCOL(lesssimpler), 30)
-  expect_that(NCOL(lesssimpler), not(is_less_than(10)))
+  expect_lt(NCOL(simpler), 15)
+  expect_gt(NCOL(simpler), 8)
+  expect_lt(NCOL(lesssimpler), 30)
+  expect_gt(NCOL(lesssimpler), 10)
 })
 
 
